@@ -25,7 +25,7 @@ from session_function import client_post_cert
 from calculate.core.client.cert_verify import VerifyError
 
 from client_class import Client_suds, HTTPSClientCertTransport
-from more import post_connect_action, show_msg, uniq, LabelWordWrap, get_icon
+from more import post_connect_action, show_msg, uniq, LabelWordWrap, get_icon, dpivalue
 
 class LocalhostPasswd(qt.QDialog):
     def __init__(self, parent):
@@ -78,7 +78,7 @@ class FrameConnection(qt.QWidget):
     def initUI(self, parent, window):
         grid = qt.QGridLayout(self)
         grid.setContentsMargins(10, 10, 10, 10)
-        grid.setSpacing(4)
+        grid.setSpacing(2)
 
         self.lbl_host = LabelWordWrap(_("Host"), self)
         self.lbl_port = LabelWordWrap(_("Port"), self)
@@ -151,7 +151,7 @@ class FrameConnection(qt.QWidget):
         
         self.setLayout(grid)
         
-        self.setFixedSize(300, 135)
+        self.setFixedSize(dpivalue(300), dpivalue(160))
         self.move(window.geometry().x() + window.geometry().width() / 2 \
                   - self.sizeHint().width() / 2, \
                   window.geometry().y() + window.geometry().height() / 2 \
